<div align="center">
<a href="https://zelenka.guru/threads/5523020/"><img width="90%" src="https://i.imgur.com/xaQ92lu.png" alt="Material Bread logo"></a>
    
[![Static Badge](https://img.shields.io/badge/DONATE-Lolzteam-darkgreen?logo=undertale&logoColor=red)](https://lzt.market/balance/transfer?user_id=2410024&comment=Thanks%20for%20creating%20LolzteamApi&amount=250)
[![License](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/AS7RIDENIED/Lolzteam_Python_Api/blob/main/LICENSE)

</div>

## Installation

*You can install the library using pip:*

```commandline
pip install LolzteamApi
```

## Usage

*Import the `LolzteamApi` module and create an instance of the `LolzteamApi` class to start using the API:*

```python
from LolzteamApi import LolzteamApi, Types
api = LolzteamApi(token='your_token')
```

## Documentation

### [Forum](https://github.com/AS7RIDENIED/Lolzteam_Python_Api/blob/main/Documentation/Forum.md) - [Market](https://github.com/AS7RIDENIED/Lolzteam_Python_Api/blob/main/Documentation/Market.md) - [Antipublic](https://github.com/AS7RIDENIED/Lolzteam_Python_Api/blob/main/Documentation/Antipublic.md) - [DelaySynchronizer](https://github.com/AS7RIDENIED/Lolzteam_Python_Api/blob/main/Documentation/DelaySynchronizer.md) - [BBCODE](https://github.com/AS7RIDENIED/Lolzteam_Python_Api/blob/main/Documentation/BBCODE.md)

## Official Lolzteam documentation

### [Forum](https://docs.api.zelenka.guru/?forum) [Market](https://docs.api.zelenka.guru/?market) [Antipublic](https://antipublic.one/docs/?antipublic)
